@@ -21,12 +21,11 @@ public:
 
     ~WaylandOutputDeviceMode() override;
 
-    int refreshRate() const;
+    QString id() const;
+    float refreshRate() const;
     QSize size() const;
     bool preferred() const;
 
-    bool operator==(const WaylandOutputDeviceMode &other);
-
     static WaylandOutputDeviceMode *get(struct ::kde_output_device_mode_v2 *object);
 
 Q_SIGNALS:
@@ -39,7 +38,8 @@ protected:
     void kde_output_device_mode_v2_removed() override;
 
 private:
-    int m_refreshRate = 60000;
+    QString m_id;
+    float m_refreshRate = 60.0;
     QSize m_size;
     bool m_preferred = false;
 };
