@@ -16,6 +16,8 @@ XRandRCrtc::XRandRCrtc(xcb_randr_crtc_t crtc, XRandRConfig *config)
     , m_crtc(crtc)
     , m_mode(0)
     , m_rotation(XCB_RANDR_ROTATION_ROTATE_0)
+    , m_timestamp(XCB_CURRENT_TIME)
+    , m_configTimestamp(XCB_CURRENT_TIME)
 {
     update();
 }
@@ -40,12 +42,12 @@ xcb_randr_rotation_t XRandRCrtc::rotation() const
     return m_rotation;
 }
 
-QVector<xcb_randr_output_t> XRandRCrtc::possibleOutputs()
+QList<xcb_randr_output_t> XRandRCrtc::possibleOutputs()
 {
     return m_possibleOutputs;
 }
 
-QVector<xcb_randr_output_t> XRandRCrtc::outputs() const
+QList<xcb_randr_output_t> XRandRCrtc::outputs() const
 {
     return m_outputs;
 }
@@ -111,3 +113,26 @@ void XRandRCrtc::update(xcb_randr_mode_t mode, xcb_randr_rotation_t rotation, co
     m_geometry = geom;
     m_rotation = rotation;
 }
+
+void XRandRCrtc::updateTimestamp(const xcb_timestamp_t tmstamp)
+{
+    if (tmstamp > m_timestamp) {
+        qCDebug(KSCREEN_XRANDR) << "XRandRCrtc " << m_crtc << " m_timestamp update " << m_timestamp << " => " << tmstamp;
+        m_timestamp = tmstamp;
+    }
+}
+
+void XRandRCrtc::updateConfigTimestamp(const xcb_timestamp_t tmstamp)
+{
+    if (tmstamp > m_configTimestamp) {
+        qCDebug(KSCREEN_XRANDR) << "XRandRCrtc " << m_crtc << " m_configTimestamp update" << m_configTimestamp << " => " << tmstamp;
+        m_configTimestamp = tmstamp;
+    }
+}
+
+bool XRandRCrtc::isChangedFromOutside() const
+{
+    return m_configTimestamp > m_timestamp;
+}
+
+#include "moc_xrandrcrtc.cpp"
