@@ -21,7 +21,8 @@ namespace ConfigSerializer
 {
 KSCREEN_EXPORT QJsonObject serializePoint(const QPoint &point);
 KSCREEN_EXPORT QJsonObject serializeSize(const QSize &size);
-template<typename T> KSCREEN_EXPORT QJsonArray serializeList(const QList<T> &list)
+template<typename T>
+KSCREEN_EXPORT QJsonArray serializeList(const QList<T> &list)
 {
     QJsonArray arr;
     for (const T &t : list) {
@@ -37,7 +38,8 @@ KSCREEN_EXPORT QJsonObject serializeScreen(const KScreen::ScreenPtr &screen);
 
 KSCREEN_EXPORT QPoint deserializePoint(const QDBusArgument &map);
 KSCREEN_EXPORT QSize deserializeSize(const QDBusArgument &map);
-template<typename T> KSCREEN_EXPORT QList<T> deserializeList(const QDBusArgument &arg)
+template<typename T>
+KSCREEN_EXPORT QList<T> deserializeList(const QDBusArgument &arg)
 {
     QList<T> list;
     arg.beginArray();
