@@ -399,7 +399,7 @@ void Doctor::parseOutputArgs()
                     m_changed = true;
                 } else if (ops.count() >= 4 && subcmd == "maxAverageBrightnessOverride") {
                     if (ops[3] == "disable") {
-                        output->setMaxPeakBrightnessOverride(std::nullopt);
+                        output->setMaxAverageBrightnessOverride(std::nullopt);
                     } else if (const uint32_t nits = ops[3].toUInt(); nits != 0) {
                         output->setMaxAverageBrightnessOverride(nits);
                     } else {
@@ -599,7 +599,7 @@ void Doctor::showOutputs() const
             auto mode = *modes.find(key);
 
             auto name = QStringLiteral("%1x%2@%3")
-                            .arg(QString::number(mode->size().width()), QString::number(mode->size().height()), QString::number(qRound(mode->refreshRate())));
+                            .arg(QString::number(mode->size().width()), QString::number(mode->size().height()), QString::number(mode->refreshRate(), 'f', 2));
             if (mode == output->currentMode()) {
                 name = green + name + QLatin1Char('*') + cr;
             }
