@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -112,7 +100,8 @@ void GetConfigOperationPrivate::onConfigReceived(QDBusPendingCallWatcher *watche
         q->emitResult();
         return;
     }
-    Q_FOREACH (const OutputPtr &output, config->outputs()) {
+    const auto outputs = config->outputs();
+    for (const OutputPtr &output : outputs) {
         if (!output->isConnected()) {
             continue;
         }
@@ -186,7 +175,9 @@ void GetConfigOperationPrivate::loadEdid(KScreen::AbstractBackend *backend)
     if (!config) {
         return;
     }
-    Q_FOREACH (auto output, config->outputs()) {
+    auto outputs = config->outputs();
+    for (auto it = outputs.begin(); it != outputs.end(); ++it) {
+        auto output = *it;
         if (output->edid() == nullptr) {
             const QByteArray edidData = backend->edid(output->id());
             output->setEdid(edidData);
@@ -195,3 +186,5 @@ void GetConfigOperationPrivate::loadEdid(KScreen::AbstractBackend *backend)
 }
 
 #include "getconfigoperation.moc"
+
+#include "moc_getconfigoperation.cpp"
